@@ -10,7 +10,8 @@ from termremind.conf import config
 
 
 def getver():
-    return "0.0.4.1"
+    return "0.0.4.7"
+
 
 VER = getver()
 
@@ -35,6 +36,11 @@ LIST_COLORS = cnfmgr.dornd()
 colors = [
     colorama.Fore.RED,
     colorama.Fore.GREEN,
+    
+    
+    
+    
+    
     colorama.Fore.YELLOW,
     colorama.Fore.CYAN,
     colorama.Fore.MAGENTA,
@@ -77,7 +83,7 @@ If you wrap text like "%bheeho%r", it will render the text "heeho" as bright tex
         .replace("%CPTH%", CONF_PATH)
         .replace("%RPTH%", REMINDERS_PATH)
     )
-    exit(0)
+    sys.exit(0)
 
 
 def main():
@@ -161,26 +167,34 @@ def main():
         else:
             print("No such option: " + action)
             exitusage()
-        exit(0)
+        sys.exit(0)
 
     else:  # no args passed
         print(THEME_COLOR + "Reminders:")
         if LIST_COLORS:
-            for rname in mgr.listermreminders():
-                print(
-                    "- "
-                    + random.choice(colors)
-                    + rname
-                    + RESET
-                    + " : "
-                    + mgr.getermreminder(rname)
-                    .replace("%b", colorama.Style.BRIGHT)
-                    .replace("%r", RESET)
-                )
+            rmds = mgr.listermreminders()
+            if rmds != []:
+                for rname in mgr.listermreminders():
+                    print(
+                        "- "
+                        + random.choice(colors)
+                        + rname
+                        + RESET
+                        + " : "
+                        + mgr.getermreminder(rname)
+                        .replace("%b", colorama.Style.BRIGHT)
+                        .replace("%r", RESET)
+                    )
+            else:
+                print(colors[0] + "No reminders found." + RESET)
         else:
-            for rname in mgr.listermreminders():
-                print("- " + rname + " : " + mgr.getermreminder(rname))
-        exit(0)
+            rmds = mgr.listermreminders()
+            if rmds != []:
+                for rname in mgr.listermreminders():
+                    print("- " + rname + " : " + mgr.getermreminder(rname))
+            else:
+                print("No reminders found")
+        sys.exit(0)
 
 
 if __name__ == "__main__":
